==> 0.0.1.tar.gz: lib/numerology.dart <==
library numerology;

import 'package:basic_utils/basic_utils.dart';
import 'package:intl/intl.dart';

/// A Calculator.
class NumerologyCalculator {
  /// Return sum of all number in the [text] if the string is digit.
  ///
  /// Otherwise, return null
  int? sumNumText(String text) {
    if (StringUtils.isDigit(text))
      return text
          .split("")
          .map((e) => int.tryParse(e))
          .reduce((value, element) => value = value! + element!)!;
    else
      return null;
  }

  /// Returns date in dd-MM-yyy format
  String toDdMnYyyy(DateTime dateTime) {
    final df = DateFormat("dd-MM-yyyy");
    return df.format(dateTime);
  }

  /// Return date in ddMMyyyy format
  String toDmy(DateTime dateTime) {
    final dmyString = toDdMnYyyy(dateTime);
    return dmyString.replaceAll("-", "");
  }

  /// Return [Ruling Number](https://destinybirthnumber.tumblr.com/post/85177033226/how-to-calculate-your-ruling-birth-numbers#:~:text=In%20the%20sixth%20century%20B.C.,46%20become%20Ruling%20Number%2010's.)
  /// for the given birthday.
  ///
  /// Ruling number can be [1,11] and 22
  int rulingNumber(DateTime birthday) {
    final dmyString = toDmy(birthday);
    int sum = sumNumText(dmyString)!;
    if (sum == 11) return 11;
    if (sum == 22) return 22;
    if (sum == 33) return 33;
    while (sum > 11) sum = sumNumText("$sum")!;
    return sum;
  }

  /// Return current [Universal Year Number](https://www.freepressjournal.in/lifestyle/numerology-predictions-for-2021-find-out-whats-in-the-store-for-you)
  ///
  /// It in the range [1, 9]
  ///
  /// This [dateTime] only use for testing purpose
  int universalYearNumber({DateTime? dateTime}) {
    DateTime calDate = DateTime.now();
    if (dateTime != null) calDate = dateTime;
    final yearString = "${calDate.year}";
    int sum = sumNumText(yearString)!;
    while (sum > 9) sum = sumNumText("$sum")!;
    return sum;
  }

  /// Return current [Personal Year](https://psychiclibrary.com/personal-year-numerology/) for person who was born in [birthday]
  ///
  /// [currentYear] only use for testing purpose
  ///
  /// It must be in range [1,9]
  int personalYear(DateTime birthday, {DateTime? currentYear}) {
    DateTime calYear = DateTime.now();
    if (currentYear != null) calYear = currentYear;
    final universalYear = universalYearNumber(dateTime: calYear);
    final calString = "${birthday.day}${birthday.month}$universalYear";
    int sum = sumNumText(calString)!;
    while (sum > 9) sum = sumNumText("$sum")!;
    return sum;
  }

  /// Return current [Personal Month](http://numerology.center/month_day_number.php) for person who was born in [birthday]
  ///
  /// It must be in range [1,9]
  int personalMonth(DateTime currentDate, DateTime birthday) {
    int perYear = personalYear(birthday, currentYear: currentDate);
    final calString = "${currentDate.month}$perYear";
    int sum = sumNumText(calString)!;
    while (sum > 9) sum = sumNumText("$sum")!;
    return sum;
  }

  /// Return [Personal Day](https://www.numerology.com/articles/about-numerology/calculate-personal-day-number/) [currentDate] of person who was born on [birthday]
  ///
  /// It must be in range [1,9] and {11, 22}
  int personalDay(DateTime currentDate, DateTime birthday) {
    final perMonth = personalMonth(currentDate, birthday);
    final calString = "${currentDate.day}$perMonth";
    int sum = sumNumText(calString)!;
    if (sum == 11) return 11;
    if (sum == 22) return 22;
    while (sum > 9) sum = sumNumText("$sum")!;
    return sum;
  }

  /// Return [Life Path Number](https://www.numerology.com/articles/your-numerology-chart/life-path-number/)
  /// of personal who was born on [birthday]
  ///
  /// It is in range [1,9] and {11, 22, 33}
  int lifePathNumber(DateTime birthday) {
    final sumDay = sumReduceNumTextWithMaster("${birthday.day}");
    final sumMonth = sumReduceNumTextWithMaster("${birthday.month}");
    final sumYear = sumReduceNumTextWithMaster("${birthday.year}");
    final calString = "$sumDay$sumMonth$sumYear";
    return sumReduceNumTextWithMaster(calString);
  }

  /// Returns [Attitude Number](https://www.astronumero.org/birthdate-numerology.html#vedenjsko-stevilo)
  /// of the person who was born in [birthday]
  ///
  /// It must be in range [1, 9]
  int attitudeNumber(DateTime birthday) {
    final calString = "${birthday.day}${birthday.month}";
    int sum = sumNumText(calString)!;
    while (sum > 9) sum = sumNumText("$sum")!;
    return sum;
  }

  /// Return sum reduce to single digit with specical [Master number](https://www.numerology.com/articles/your-numerology-chart/life-path-number/)
  /// , 11, 22, and 33
  ///
  /// It must be in range [1, 9] and {11, 22, 33}
  ///
  /// [text] must be a digit string
  int sumReduceNumTextWithMaster(String text) {
    assert(StringUtils.isDigit(text));
    int sum = sumNumText(text)!;
    if (sum == 11) return 11;
    if (sum == 22) return 22;
    if (sum == 33) return 33;
    while (sum > 9) sum = sumNumText("$sum")!;
    return sum;
  }

  /// Return sum reduce to single digit in range [1, 9]
  ///
  /// [text] must be a deigt string
  int sumReduceNumText(String text) {
    assert(StringUtils.isDigit(text));
    int sum = sumNumText(text)!;
    while (sum > 9) sum = sumNumText("$sum")!;
    return sum;
  }
}

==> 0.0.4.tar.gz: lib/numerology.dart <==
library numerology;

import 'package:basic_utils/basic_utils.dart';
import 'package:intl/intl.dart';

/// A Calculator.
class NumerologyCalculator {
  /// Return sum of all number in the [text] if the string is digit.
  ///
  /// Otherwise, return null
  ///
  /// [text] must be a digit string
  int sumNumText(String text) {
    assert(StringUtils.isDigit(text));
    return text
        .split("")
        .map((e) => int.tryParse(e))
        .reduce((value, element) => value = value! + element!)!;
  }

  /// Returns date in dd-MM-yyy format
  String toDdMnYyyy(DateTime dateTime) {
    final df = DateFormat("dd-MM-yyyy");
    return df.format(dateTime);
  }

  /// Return date in ddMMyyyy format
  String toDmy(DateTime dateTime) {
    final dmyString = toDdMnYyyy(dateTime);
    return dmyString.replaceAll("-", "");
  }

  /// Return [Ruling Number](https://destinybirthnumber.tumblr.com/post/85177033226/how-to-calculate-your-ruling-birth-numbers#:~:text=In%20the%20sixth%20century%20B.C.,46%20become%20Ruling%20Number%2010's.)
  /// for the given birthday.
  ///
  /// Ruling number can be [1,11] and 22
  int rulingNumber(DateTime birthday) {
    final dmyString = toDmy(birthday);
    int sum = sumNumText(dmyString);
    if (sum == 11) return 11;
    if (sum == 22) return 22;
    if (sum == 33) return 33;
    while (sum > 11) sum = sumNumText("$sum");
    return sum;
  }

  /// Return current [Universal Year Number](https://www.freepressjournal.in/lifestyle/numerology-predictions-for-2021-find-out-whats-in-the-store-for-you)
  ///
  /// It in the range [1, 9]
  ///
  /// This [dateTime] only use for testing purpose
  int universalYearNumber({DateTime? dateTime}) {
    DateTime calDate = DateTime.now();
    if (dateTime != null) calDate = dateTime;
    final yearString = "${calDate.year}";
    int sum = sumNumText(yearString);
    while (sum > 9) sum = sumNumText("$sum");
    return sum;
  }

  /// Return current [Personal Year](https://psychiclibrary.com/personal-year-numerology/) for person who was born in [birthday]
  ///
  /// [currentYear] only use for testing purpose
  ///
  /// It must be in range [1,9]
  int personalYear(DateTime birthday, {DateTime? currentYear}) {
    DateTime calYear = DateTime.now();
    if (currentYear != null) calYear = currentYear;
    final universalYear = universalYearNumber(dateTime: calYear);
    final calString = "${birthday.day}${birthday.month}$universalYear";
    int sum = sumNumText(calString);
    while (sum > 9) sum = sumNumText("$sum");
    return sum;
  }

  /// Return current [Personal Month](http://numerology.center/month_day_number.php) for person who was born in [birthday]
  ///
  /// It must be in range [1,9]
  int personalMonth(DateTime currentDate, DateTime birthday) {
    int perYear = personalYear(birthday, currentYear: currentDate);
    final calString = "${currentDate.month}$perYear";
    int sum = sumNumText(calString);
    while (sum > 9) sum = sumNumText("$sum");
    return sum;
  }

  /// Return [Personal Day](https://www.numerology.com/articles/about-numerology/calculate-personal-day-number/) [currentDate] of person who was born on [birthday]
  ///
  /// It must be in range [1,9] and {11, 22}
  int personalDay(DateTime currentDate, DateTime birthday) {
    final perMonth = personalMonth(currentDate, birthday);
    final calString = "${currentDate.day}$perMonth";
    int sum = sumNumText(calString);
    if (sum == 11) return 11;
    if (sum == 22) return 22;
    while (sum > 9) sum = sumNumText("$sum");
    return sum;
  }

  /// Return [Life Path Number](https://www.numerology.com/articles/your-numerology-chart/life-path-number/)
  /// of personal who was born on [birthday]
  ///
  /// It is in range [1,9] and {11, 22, 33}
  int lifePathNumber(DateTime birthday) {
    final sumDay = sumReduceNumTextWithMaster("${birthday.day}");
    final sumMonth = sumReduceNumTextWithMaster("${birthday.month}");
    final sumYear = sumReduceNumTextWithMaster("${birthday.year}");
    final calString = "$sumDay$sumMonth$sumYear";
    return sumReduceNumTextWithMaster(calString);
  }

  /// Returns [Attitude Number](https://www.astronumero.org/birthdate-numerology.html#vedenjsko-stevilo)
  /// of the person who was born in [birthday]
  ///
  /// It must be in range [1, 9]
  int attitudeNumber(DateTime birthday) {
    final calString = "${birthday.day}${birthday.month}";
    int sum = sumNumText(calString);
    while (sum > 9) sum = sumNumText("$sum");
    return sum;
  }

  /// Return sum reduce to single digit with specical [Master number](https://www.numerology.com/articles/your-numerology-chart/life-path-number/)
  /// , 11, 22, and 33
  ///
  /// It must be in range [1, 9] and {11, 22, 33}
  ///
  /// [text] must be a digit string
  int sumReduceNumTextWithMaster(String text) {
    assert(StringUtils.isDigit(text));
    int sum = sumNumText(text);
    if (sum == 11) return 11;
    if (sum == 22) return 22;
    if (sum == 33) return 33;
    while (sum > 9) sum = sumNumText("$sum");
    return sum;
  }

  /// Return sum reduce to single digit in range [1, 9]
  ///
  /// [text] must be a deigt string
  int sumReduceNumText(String text) {
    assert(StringUtils.isDigit(text));
    int sum = sumNumText(text);
    while (sum > 9) sum = sumNumText("$sum");
    return sum;
  }
}
